import { _ as __assign, d as __spreadArray } from '../../tslib.es6-a941f97f.js';
import { r as reactTable } from '../../index-b6c1b619.js';
import React, { useEffect } from 'react';
import { S as SELECTION_COLUMN_ID } from '../../constants-cdb4cae7.js';
import '../../_commonjsHelpers-41cdd1e7.js';

var SET_STICKY_COLUMN_ACTION = 'SET_STICKY_TABLE_COLUMN';
var RESET_STICKY_COLUMNS_ACTION = 'RESET_STICKY_COLUMNS_ACTION';
var checkErrors = function (columns) {
    var hasGroups = !!columns.find(function (column) { return column.parent; });
    var stickyColumnsWithoutGroup = columns
        .filter(function (column) { return column.sticky && !column.parent; })
        .map(function (_a) {
        var Header = _a.Header;
        return "'" + Header + "'";
    });
    if (hasGroups && stickyColumnsWithoutGroup.length) {
        throw new Error("WARNING react-table-sticky:\n      \nYour ReactTable has group and sticky columns outside groups, and that will break UI.\n      \nYou must place " + stickyColumnsWithoutGroup.join(' and ') + " columns into a group (even a group with an empty Header label)\n");
    }
    var bugWithUnderColumnsSticky = columns.find(function (parentCol) {
        return !parentCol.sticky &&
            parentCol.columns &&
            parentCol.columns.find(function (col) { return col.sticky; });
    });
    if (!bugWithUnderColumnsSticky)
        return;
    var childBugs = bugWithUnderColumnsSticky.columns.find(function (_a) {
        var sticky = _a.sticky;
        return sticky;
    });
    if (!childBugs)
        return;
    throw new Error("WARNING react-table-sticky:\n    \nYour ReactTable contain columns group with at least one child columns sticky.\n    \nWhen ReactTable has columns groups, only columns groups can be sticky\n    \nYou must set sticky: 'left' | 'right' for the '" + bugWithUnderColumnsSticky.Header + "'\n    column, or remove the sticky property of '" + childBugs.Header + "' column.");
};
function getStickyValue(column) {
    if (column.sticky === 'left' || column.sticky === 'right') {
        return column.sticky;
    }
    if (column.parent) {
        return getStickyValue(column.parent);
    }
    return null;
}
function columnIsLastLeftSticky(columnId, columns) {
    var index = columns.findIndex(function (_a) {
        var id = _a.id;
        return id === columnId;
    });
    var column = columns[index];
    var nextColumn = columns[index + 1];
    var columnIsLeftSticky = getStickyValue(column) === 'left';
    var nextColumnIsLeftSticky = nextColumn && getStickyValue(nextColumn) === 'left';
    return columnIsLeftSticky && !nextColumnIsLeftSticky;
}
function columnIsFirstRightSticky(columnId, columns) {
    var index = columns.findIndex(function (_a) {
        var id = _a.id;
        return id === columnId;
    });
    var column = columns[index];
    var prevColumn = columns[index - 1];
    var columnIsRightSticky = getStickyValue(column) === 'right';
    var prevColumnIsRightSticky = prevColumn && getStickyValue(prevColumn) === 'right';
    return columnIsRightSticky && !prevColumnIsRightSticky;
}
function getMarginRight(columnId, columns) {
    var currentIndex = columns.findIndex(function (_a) {
        var id = _a.id;
        return id === columnId;
    });
    var rightMargin = 0;
    for (var i = currentIndex + 1; i < columns.length; i += 1) {
        if (columns[i].isVisible !== false) {
            rightMargin += columns[i].width;
        }
    }
    return rightMargin;
}
var cellStylesSticky = {
    position: 'sticky',
    zIndex: 3,
};
function findHeadersSameLevel(header, headers) {
    return headers.filter(function (flatHeaderItem) {
        return flatHeaderItem.depth === header.depth;
    });
}
function getStickyProps(header, instance) {
    var _a;
    var style = {};
    var dataAttrs = {};
    checkErrors(instance.columns);
    var sticky = getStickyValue(header);
    if (sticky) {
        style = __assign({}, cellStylesSticky);
        dataAttrs['data-sticky-td'] = true;
        var headers = findHeadersSameLevel(header, instance.flatHeaders);
        var margin = sticky === 'left' ? header.totalLeft : getMarginRight(header.id, headers);
        style = __assign(__assign({}, style), (_a = {}, _a[sticky] = margin + "px", _a));
        var isLastLeftSticky = columnIsLastLeftSticky(header.id, headers);
        if (isLastLeftSticky) {
            dataAttrs['data-sticky-last-left-td'] = true;
        }
        var isFirstRightSticky = columnIsFirstRightSticky(header.id, headers);
        if (isFirstRightSticky) {
            dataAttrs['data-sticky-first-right-td'] = true;
        }
    }
    return __assign({ style: style }, dataAttrs);
}
function useInstance(instance) {
    var tableKey = instance.tableKey, flatHeaders = instance.flatHeaders, dispatch = instance.dispatch, _a = instance.state, leftStickyColumns = _a.leftStickyColumns, rightStickyColumns = _a.rightStickyColumns;
    var resetAllStickyColumns = React.useCallback(function () { return dispatch({ type: RESET_STICKY_COLUMNS_ACTION }); }, [dispatch]);
    var setStickyColumn = React.useCallback(function (value, columnId) {
        return dispatch({
            type: SET_STICKY_COLUMN_ACTION,
            columnId: columnId,
            value: value,
        });
    }, [dispatch]);
    useEffect(function () {
        localStorage.setItem(tableKey + '_leftStickyColumns', JSON.stringify(leftStickyColumns));
    }, [leftStickyColumns, tableKey]);
    useEffect(function () {
        localStorage.setItem(tableKey + '_rightStickyColumns', JSON.stringify(rightStickyColumns));
    }, [rightStickyColumns, tableKey]);
    flatHeaders.forEach(function (column, index) {
        var isLeft = leftStickyColumns.includes(column.id);
        var isRight = rightStickyColumns.includes(column.id);
        column.sticky = isLeft ? 'left' : isRight ? 'right' : undefined;
        column.setSticky = function (value) {
            if (value !== column.sticky)
                setStickyColumn(value, column.id);
        };
    });
    Object.assign(instance, {
        resetAllStickyColumns: resetAllStickyColumns,
    });
}
function reducer(state, action, previousState, instance) {
    function getDefaultStickyColumns(type) {
        var columns = instance.columns;
        var defaultColumns = columns
            .filter(function (column) { return column.sticky === type; })
            .map(function (column) {
            return column.id || column.accessor || column.Header;
        });
        if (type === 'left')
            defaultColumns.push(SELECTION_COLUMN_ID);
        return defaultColumns;
    }
    if (action.type === reactTable.actions.init) {
        var getStickyColumns = function (type) {
            var storageStickyColumns = localStorage.getItem(instance.tableKey + "_" + type + "StickyColumns")
                ? JSON.parse(localStorage.getItem(instance.tableKey + "_" + type + "StickyColumns"))
                : undefined;
            if (Array.isArray(storageStickyColumns) &&
                storageStickyColumns.length > 0)
                return storageStickyColumns;
            return getDefaultStickyColumns(type);
        };
        var leftStickyColumns = getStickyColumns('left');
        return __assign(__assign({}, state), { leftStickyColumns: leftStickyColumns.includes(SELECTION_COLUMN_ID)
                ? leftStickyColumns
                : __spreadArray([SELECTION_COLUMN_ID], leftStickyColumns), rightStickyColumns: __spreadArray([], getStickyColumns('right')) });
    }
    if (action.type === SET_STICKY_COLUMN_ACTION) {
        switch (action.value) {
            case 'left':
                return __assign(__assign({}, state), { leftStickyColumns: __spreadArray(__spreadArray([], state.leftStickyColumns), [action.columnId]), rightStickyColumns: state.rightStickyColumns.filter(function (item) { return item !== action.columnId; }) });
            case 'right':
                return __assign(__assign({}, state), { rightStickyColumns: __spreadArray(__spreadArray([], state.rightStickyColumns), [action.columnId]), leftStickyColumns: state.leftStickyColumns.filter(function (item) { return item !== action.columnId; }) });
            default:
                return __assign(__assign({}, state), { leftStickyColumns: state.leftStickyColumns.filter(function (item) { return item !== action.columnId; }), rightStickyColumns: state.rightStickyColumns.filter(function (item) { return item !== action.columnId; }) });
        }
    }
    if (action.type === RESET_STICKY_COLUMNS_ACTION) {
        return __assign(__assign({}, state), { leftStickyColumns: getDefaultStickyColumns('left'), rightStickyColumns: getDefaultStickyColumns('right') });
    }
}
var useSticky = function (hooks) {
    hooks.useInstance.push(useInstance);
    hooks.stateReducers.push(reducer);
    hooks.getHeaderProps.push(function (props, _a) {
        var instance = _a.instance, column = _a.column;
        var nextProps = getStickyProps(column, instance);
        return [props, nextProps];
    });
    hooks.getCellProps.push(function (props, _a) {
        var instance = _a.instance, cell = _a.cell;
        var nextProps = getStickyProps(cell.column, instance);
        return [props, nextProps];
    });
};
useSticky.pluginName = 'useSticky';

export { checkErrors, columnIsFirstRightSticky, columnIsLastLeftSticky, getMarginRight, getStickyValue, useSticky };
//# sourceMappingURL=useSticky.js.map
