import { c as __rest, _ as __assign } from '../tslib.es6-a941f97f.js';
import { jsxs, jsx } from 'react/jsx-runtime';
import { cloneElement, createElement, Fragment, forwardRef, useRef, useState, useCallback, useEffect, useMemo } from 'react';
import { a as useFormikContext } from '../formik.esm-06fc6bc4.js';
import { g as get_1 } from '../get-fc89bca9.js';
import { d as debounce_1 } from '../debounce-b9a8de1b.js';
import { m as makeStyles } from '../makeStyles-5b784462.js';
import { G as Grid } from '../Grid-f6c53e5a.js';
import { _ as _objectWithoutPropertiesLoose } from '../objectWithoutPropertiesLoose-6856ddd5.js';
import { _ as _extends } from '../extends-e61fd370.js';
import { p as propTypes } from '../index-df27ca20.js';
import { c as clsx } from '../clsx.m-6243b874.js';
import { g as generateUtilityClass, a as generateUtilityClasses, j as useControlled, l as useForkRef, k as useEventCallback, i as useEnhancedEffect, c as composeClasses, e as experimentalStyled, C as lighten, D as darken, f as alpha, u as useThemeProps, b as capitalize, d as deepmerge } from '../experimentalStyled-9a0c9477.js';
import { i as isHostComponent } from '../isHostComponent-7b82e20e.js';
import { u as useIsFocusVisible } from '../useIsFocusVisible-7eb97459.js';
import { o as ownerDocument } from '../ownerDocument-08286491.js';
import { c as chainPropTypes } from '../refType-2daf2908.js';
import { I as Input } from '../Input-505624cb.js';
import '../tiny-warning.esm-9caf1e37.js';
import '../hoist-non-react-statics.cjs-887936b4.js';
import '../_MapCache-a3d3cd04.js';
import '../_commonjsHelpers-41cdd1e7.js';
import '../makeStyles-3f0becbd.js';
import '../toConsumableArray-14d095fd.js';
import '../inheritsLoose-8d9312ec.js';
import '../setPrototypeOf-38804714.js';
import '../assertThisInitialized-d8516fd7.js';
import '../exactProp-2b7ae831.js';
import '../extendSxProp-f37d7304.js';
import '../requirePropFactory-762b28b9.js';
import '../InputBase-ac030ecb.js';
import '../utils-a2178b2f.js';
import '../FormControlContext-3e99c910.js';
import '../ownerWindow-511cbe55.js';
import '../emotion-react.esm-10db94ea.js';
import '../elementTypeAcceptingRef-58d95132.js';

const visuallyHidden = {
  border: 0,
  clip: 'rect(0 0 0 0)',
  height: '1px',
  margin: -1,
  overflow: 'hidden',
  padding: 0,
  position: 'absolute',
  whiteSpace: 'nowrap',
  width: '1px'
};

function getSliderUtilityClass(slot) {
  return generateUtilityClass('MuiSlider', slot);
}
const sliderUnstyledClasses = generateUtilityClasses('MuiSlider', ['root', 'active', 'focusVisible', 'disabled', 'dragging', 'marked', 'vertical', 'trackInverted', 'trackFalse', 'rail', 'track', 'mark', 'markActive', 'markLabel', 'markLabelActive', 'thumb', 'valueLabel', 'valueLabelOpen', 'valueLabelCircle', 'valueLabelLabel']);

const useValueLabelClasses = props => {
  const {
    open
  } = props;
  const utilityClasses = {
    offset: clsx(open && sliderUnstyledClasses.valueLabelOpen),
    circle: sliderUnstyledClasses.valueLabelCircle,
    label: sliderUnstyledClasses.valueLabelLabel
  };
  return utilityClasses;
};
/**
 * @ignore - internal component.
 */


function SliderValueLabelUnstyled(props) {
  const {
    children,
    className,
    value,
    theme
  } = props;
  const classes = useValueLabelClasses(props);
  return /*#__PURE__*/cloneElement(children, {
    className: clsx(children.props.className)
  }, /*#__PURE__*/createElement(Fragment, null, children.props.children, /*#__PURE__*/createElement("span", {
    className: clsx(classes.offset, className),
    theme: theme,
    "aria-hidden": true
  }, /*#__PURE__*/createElement("span", {
    className: classes.circle
  }, /*#__PURE__*/createElement("span", {
    className: classes.label
  }, value)))));
}

process.env.NODE_ENV !== "production" ? SliderValueLabelUnstyled.propTypes = {
  children: propTypes.element.isRequired,
  className: propTypes.string,
  theme: propTypes.any,
  value: propTypes.node
} : void 0;

const INTENTIONAL_DRAG_COUNT_THRESHOLD = 2;

function asc(a, b) {
  return a - b;
}

function clamp(value, min, max) {
  if (value == null) {
    return min;
  }

  return Math.min(Math.max(min, value), max);
}

function findClosest(values, currentValue) {
  const {
    index: closestIndex
  } = values.reduce((acc, value, index) => {
    const distance = Math.abs(currentValue - value);

    if (acc === null || distance < acc.distance || distance === acc.distance) {
      return {
        distance,
        index
      };
    }

    return acc;
  }, null);
  return closestIndex;
}

function trackFinger(event, touchId) {
  if (touchId.current !== undefined && event.changedTouches) {
    for (let i = 0; i < event.changedTouches.length; i += 1) {
      const touch = event.changedTouches[i];

      if (touch.identifier === touchId.current) {
        return {
          x: touch.clientX,
          y: touch.clientY
        };
      }
    }

    return false;
  }

  return {
    x: event.clientX,
    y: event.clientY
  };
}

function valueToPercent(value, min, max) {
  return (value - min) * 100 / (max - min);
}

function percentToValue(percent, min, max) {
  return (max - min) * percent + min;
}

function getDecimalPrecision(num) {
  // This handles the case when num is very small (0.00000001), js will turn this into 1e-8.
  // When num is bigger than 1 or less than -1 it won't get converted to this notation so it's fine.
  if (Math.abs(num) < 1) {
    const parts = num.toExponential().split('e-');
    const matissaDecimalPart = parts[0].split('.')[1];
    return (matissaDecimalPart ? matissaDecimalPart.length : 0) + parseInt(parts[1], 10);
  }

  const decimalPart = num.toString().split('.')[1];
  return decimalPart ? decimalPart.length : 0;
}

function roundValueToStep(value, step, min) {
  const nearest = Math.round((value - min) / step) * step + min;
  return Number(nearest.toFixed(getDecimalPrecision(step)));
}

function setValueIndex({
  values,
  source,
  newValue,
  index
}) {
  // Performance shortcut
  if (source[index] === newValue) {
    return source;
  }

  const output = values.slice();
  output[index] = newValue;
  return output;
}

function focusThumb({
  sliderRef,
  activeIndex,
  setActive
}) {
  const doc = ownerDocument(sliderRef.current);

  if (!sliderRef.current.contains(doc.activeElement) || Number(doc.activeElement.getAttribute('data-index')) !== activeIndex) {
    sliderRef.current.querySelector(`[type="range"][data-index="${activeIndex}"]`).focus();
  }

  if (setActive) {
    setActive(activeIndex);
  }
}

const axisProps = {
  horizontal: {
    offset: percent => ({
      left: `${percent}%`
    }),
    leap: percent => ({
      width: `${percent}%`
    })
  },
  'horizontal-reverse': {
    offset: percent => ({
      right: `${percent}%`
    }),
    leap: percent => ({
      width: `${percent}%`
    })
  },
  vertical: {
    offset: percent => ({
      bottom: `${percent}%`
    }),
    leap: percent => ({
      height: `${percent}%`
    })
  }
};

const Identity = x => x; // TODO: remove support for Safari < 13.
// https://caniuse.com/#search=touch-action
//
// Safari, on iOS, supports touch action since v13.
// Over 80% of the iOS phones are compatible
// in August 2020.


let cachedSupportsTouchActionNone;

function doesSupportTouchActionNone() {
  if (cachedSupportsTouchActionNone === undefined) {
    const element = document.createElement('div');
    element.style.touchAction = 'none';
    document.body.appendChild(element);
    cachedSupportsTouchActionNone = window.getComputedStyle(element).touchAction === 'none';
    element.parentElement.removeChild(element);
  }

  return cachedSupportsTouchActionNone;
}

const useUtilityClasses = styleProps => {
  const {
    disabled,
    dragging,
    marked,
    orientation,
    track,
    classes
  } = styleProps;
  const slots = {
    root: ['root', disabled && 'disabled', dragging && 'dragging', marked && 'marked', orientation === 'vertical' && 'vertical', track === 'inverted' && 'trackInverted', track === false && 'trackFalse'],
    rail: ['rail'],
    track: ['track'],
    mark: ['mark'],
    markActive: ['markActive'],
    markLabel: ['markLabel'],
    markLabelActive: ['markLabelActive'],
    valueLabel: ['valueLabel'],
    thumb: ['thumb', disabled && 'disabled'],
    active: ['active'],
    disabled: ['disabled'],
    focusVisible: ['focusVisible']
  };
  return composeClasses(slots, getSliderUtilityClass, classes);
};

const Forward = ({
  children
}) => children;

const SliderUnstyled = /*#__PURE__*/forwardRef(function SliderUnstyled(props, ref) {
  const {
    'aria-label': ariaLabel,
    'aria-labelledby': ariaLabelledby,
    'aria-valuetext': ariaValuetext,
    className,
    component = 'span',
    classes: classesProp,
    defaultValue,
    disabled = false,
    getAriaLabel,
    getAriaValueText,
    marks: marksProp = false,
    max = 100,
    min = 0,
    name,
    onChange,
    onChangeCommitted,
    onMouseDown,
    orientation = 'horizontal',
    scale = Identity,
    step = 1,
    track = 'normal',
    value: valueProp,
    valueLabelDisplay = 'off',
    valueLabelFormat = Identity,
    isRtl = false,
    components = {},
    componentsProps = {},

    /* eslint-disable-next-line react/prop-types */
    theme
  } = props,
        other = _objectWithoutPropertiesLoose(props, ["aria-label", "aria-labelledby", "aria-valuetext", "className", "component", "classes", "defaultValue", "disabled", "getAriaLabel", "getAriaValueText", "marks", "max", "min", "name", "onChange", "onChangeCommitted", "onMouseDown", "orientation", "scale", "step", "track", "value", "valueLabelDisplay", "valueLabelFormat", "isRtl", "components", "componentsProps", "theme"]);

  const touchId = useRef(); // We can't use the :active browser pseudo-classes.
  // - The active state isn't triggered when clicking on the rail.
  // - The active state isn't transferred when inversing a range slider.

  const [active, setActive] = useState(-1);
  const [open, setOpen] = useState(-1);
  const [dragging, setDragging] = useState(false);
  const moveCount = useRef(0);
  const [valueDerived, setValueState] = useControlled({
    controlled: valueProp,
    default: defaultValue !== null && defaultValue !== void 0 ? defaultValue : min,
    name: 'Slider'
  });

  const handleChange = onChange && ((event, value) => {
    // Redefine target to allow name and value to be read.
    // This allows seamless integration with the most popular form libraries.
    // https://github.com/mui-org/material-ui/issues/13485#issuecomment-676048492
    // Clone the event to not override `target` of the original event.
    const nativeEvent = event.nativeEvent || event;
    const clonedEvent = new nativeEvent.constructor(nativeEvent.type, nativeEvent);
    Object.defineProperty(clonedEvent, 'target', {
      writable: true,
      value: {
        value,
        name
      }
    });
    onChange(clonedEvent, value);
  });

  const range = Array.isArray(valueDerived);
  let values = range ? valueDerived.slice().sort(asc) : [valueDerived];
  values = values.map(value => clamp(value, min, max));
  const marks = marksProp === true && step !== null ? [...Array(Math.floor((max - min) / step) + 1)].map((_, index) => ({
    value: min + step * index
  })) : marksProp || [];
  const {
    isFocusVisibleRef,
    onBlur: handleBlurVisible,
    onFocus: handleFocusVisible,
    ref: focusVisibleRef
  } = useIsFocusVisible();
  const [focusVisible, setFocusVisible] = useState(-1);
  const sliderRef = useRef();
  const handleFocusRef = useForkRef(focusVisibleRef, sliderRef);
  const handleRef = useForkRef(ref, handleFocusRef);
  const handleFocus = useEventCallback(event => {
    const index = Number(event.currentTarget.getAttribute('data-index'));
    handleFocusVisible(event);

    if (isFocusVisibleRef.current === true) {
      setFocusVisible(index);
    }

    setOpen(index);
  });
  const handleBlur = useEventCallback(event => {
    handleBlurVisible(event);

    if (isFocusVisibleRef.current === false) {
      setFocusVisible(-1);
    }

    setOpen(-1);
  });
  const handleMouseOver = useEventCallback(event => {
    const index = Number(event.currentTarget.getAttribute('data-index'));
    setOpen(index);
  });
  const handleMouseLeave = useEventCallback(() => {
    setOpen(-1);
  });
  useEnhancedEffect(() => {
    if (disabled && sliderRef.current.contains(document.activeElement)) {
      // This is necessary because Firefox and Safari will keep focus
      // on a disabled element:
      // https://codesandbox.io/s/mui-pr-22247-forked-h151h?file=/src/App.js
      document.activeElement.blur();
    }
  }, [disabled]);

  if (disabled && active !== -1) {
    setActive(-1);
  }

  if (disabled && focusVisible !== -1) {
    setFocusVisible(-1);
  }

  const handleHiddenInputChange = useEventCallback(event => {
    const index = Number(event.currentTarget.getAttribute('data-index'));
    const value = values[index];
    const marksValues = marks.map(mark => mark.value);
    const marksIndex = marksValues.indexOf(value);
    let newValue = event.target.valueAsNumber;

    if (marks && step == null) {
      newValue = newValue < value ? marksValues[marksIndex - 1] : marksValues[marksIndex + 1];
    }

    newValue = clamp(newValue, min, max);

    if (marks && step == null) {
      const markValues = marks.map(mark => mark.value);
      const currentMarkIndex = markValues.indexOf(values[index]);
      newValue = newValue < values[index] ? markValues[currentMarkIndex - 1] : markValues[currentMarkIndex + 1];
    }

    if (range) {
      const previousValue = newValue;
      newValue = setValueIndex({
        values,
        source: valueDerived,
        newValue,
        index
      }).sort(asc);
      focusThumb({
        sliderRef,
        activeIndex: newValue.indexOf(previousValue)
      });
    }

    setValueState(newValue);
    setFocusVisible(index);

    if (handleChange) {
      handleChange(event, newValue);
    }

    if (onChangeCommitted) {
      onChangeCommitted(event, newValue);
    }
  });
  const previousIndex = useRef();
  let axis = orientation;

  if (isRtl && orientation !== "vertical") {
    axis += '-reverse';
  }

  const getFingerNewValue = ({
    finger,
    move = false,
    values: values2,
    source
  }) => {
    const {
      current: slider
    } = sliderRef;
    const {
      width,
      height,
      bottom,
      left
    } = slider.getBoundingClientRect();
    let percent;

    if (axis.indexOf('vertical') === 0) {
      percent = (bottom - finger.y) / height;
    } else {
      percent = (finger.x - left) / width;
    }

    if (axis.indexOf('-reverse') !== -1) {
      percent = 1 - percent;
    }

    let newValue;
    newValue = percentToValue(percent, min, max);

    if (step) {
      newValue = roundValueToStep(newValue, step, min);
    } else {
      const marksValues = marks.map(mark => mark.value);
      const closestIndex = findClosest(marksValues, newValue);
      newValue = marksValues[closestIndex];
    }

    newValue = clamp(newValue, min, max);
    let activeIndex = 0;

    if (range) {
      if (!move) {
        activeIndex = findClosest(values2, newValue);
      } else {
        activeIndex = previousIndex.current;
      }

      const previousValue = newValue;
      newValue = setValueIndex({
        values: values2,
        source,
        newValue,
        index: activeIndex
      }).sort(asc);
      activeIndex = newValue.indexOf(previousValue);
      previousIndex.current = activeIndex;
    }

    return {
      newValue,
      activeIndex
    };
  };

  const handleTouchMove = useEventCallback(nativeEvent => {
    const finger = trackFinger(nativeEvent, touchId);

    if (!finger) {
      return;
    }

    moveCount.current += 1; // Cancel move in case some other element consumed a mouseup event and it was not fired.

    if (nativeEvent.type === 'mousemove' && nativeEvent.buttons === 0) {
      // eslint-disable-next-line @typescript-eslint/no-use-before-define
      handleTouchEnd(nativeEvent);
      return;
    }

    const {
      newValue,
      activeIndex
    } = getFingerNewValue({
      finger,
      move: true,
      values,
      source: valueDerived
    });
    focusThumb({
      sliderRef,
      activeIndex,
      setActive
    });
    setValueState(newValue);

    if (!dragging && moveCount.current > INTENTIONAL_DRAG_COUNT_THRESHOLD) {
      setDragging(true);
    }

    if (handleChange) {
      handleChange(nativeEvent, newValue);
    }
  });
  const handleTouchEnd = useEventCallback(nativeEvent => {
    const finger = trackFinger(nativeEvent, touchId);
    setDragging(false);

    if (!finger) {
      return;
    }

    const {
      newValue
    } = getFingerNewValue({
      finger,
      values,
      source: valueDerived
    });
    setActive(-1);

    if (nativeEvent.type === 'touchend') {
      setOpen(-1);
    }

    if (onChangeCommitted) {
      onChangeCommitted(nativeEvent, newValue);
    }

    touchId.current = undefined; // eslint-disable-next-line @typescript-eslint/no-use-before-define

    stopListening();
  });
  const handleTouchStart = useEventCallback(nativeEvent => {
    // If touch-action: none; is not supported we need to prevent the scroll manually.
    if (!doesSupportTouchActionNone()) {
      nativeEvent.preventDefault();
    }

    const touch = nativeEvent.changedTouches[0];

    if (touch != null) {
      // A number that uniquely identifies the current finger in the touch session.
      touchId.current = touch.identifier;
    }

    const finger = trackFinger(nativeEvent, touchId);
    const {
      newValue,
      activeIndex
    } = getFingerNewValue({
      finger,
      values,
      source: valueDerived
    });
    focusThumb({
      sliderRef,
      activeIndex,
      setActive
    });
    setValueState(newValue);

    if (handleChange) {
      handleChange(nativeEvent, newValue);
    }

    moveCount.current = 0;
    const doc = ownerDocument(sliderRef.current);
    doc.addEventListener('touchmove', handleTouchMove);
    doc.addEventListener('touchend', handleTouchEnd);
  });
  const stopListening = useCallback(() => {
    const doc = ownerDocument(sliderRef.current);
    doc.removeEventListener('mousemove', handleTouchMove);
    doc.removeEventListener('mouseup', handleTouchEnd);
    doc.removeEventListener('touchmove', handleTouchMove);
    doc.removeEventListener('touchend', handleTouchEnd);
  }, [handleTouchEnd, handleTouchMove]);
  useEffect(() => {
    const {
      current: slider
    } = sliderRef;
    slider.addEventListener('touchstart', handleTouchStart, {
      passive: doesSupportTouchActionNone()
    });
    return () => {
      slider.removeEventListener('touchstart', handleTouchStart, {
        passive: doesSupportTouchActionNone()
      });
      stopListening();
    };
  }, [stopListening, handleTouchStart]);
  useEffect(() => {
    if (disabled) {
      stopListening();
    }
  }, [disabled, stopListening]);
  const handleMouseDown = useEventCallback(event => {
    if (onMouseDown) {
      onMouseDown(event);
    } // Only handle left clicks


    if (event.button !== 0) {
      return;
    } // Avoid text selection


    event.preventDefault();
    const finger = trackFinger(event, touchId);
    const {
      newValue,
      activeIndex
    } = getFingerNewValue({
      finger,
      values,
      source: valueDerived
    });
    focusThumb({
      sliderRef,
      activeIndex,
      setActive
    });
    setValueState(newValue);

    if (handleChange) {
      handleChange(event, newValue);
    }

    moveCount.current = 0;
    const doc = ownerDocument(sliderRef.current);
    doc.addEventListener('mousemove', handleTouchMove);
    doc.addEventListener('mouseup', handleTouchEnd);
  });
  const trackOffset = valueToPercent(range ? values[0] : min, min, max);
  const trackLeap = valueToPercent(values[values.length - 1], min, max) - trackOffset;

  const trackStyle = _extends({}, axisProps[axis].offset(trackOffset), axisProps[axis].leap(trackLeap));

  const Root = components.Root || component;
  const rootProps = componentsProps.root || {};
  const Rail = components.Rail || 'span';
  const railProps = componentsProps.rail || {};
  const Track = components.Track || 'span';
  const trackProps = componentsProps.track || {};
  const Thumb = components.Thumb || 'span';
  const thumbProps = componentsProps.thumb || {};
  const ValueLabel = components.ValueLabel || SliderValueLabelUnstyled;
  const valueLabelProps = componentsProps.valueLabel || {};
  const Mark = components.Mark || 'span';
  const markProps = componentsProps.mark || {};
  const MarkLabel = components.MarkLabel || 'span';
  const markLabelProps = componentsProps.markLabel || {}; // all props with defaults
  // consider extracting to hook an reusing the lint rule for the varints

  const styleProps = _extends({}, props, {
    classes: classesProp,
    disabled,
    dragging,
    isRtl,
    marked: marks.length > 0 && marks.some(mark => mark.label),
    max,
    min,
    orientation,
    scale,
    step,
    track,
    valueLabelDisplay,
    valueLabelFormat
  });

  const classes = useUtilityClasses(styleProps);
  return /*#__PURE__*/createElement(Root, _extends({
    ref: handleRef,
    onMouseDown: handleMouseDown
  }, rootProps, !isHostComponent(Root) && {
    as: component,
    styleProps: _extends({}, styleProps, rootProps.styleProps),
    theme
  }, other, {
    className: clsx(classes.root, rootProps.className, className)
  }), /*#__PURE__*/createElement(Rail, _extends({}, railProps, !isHostComponent(Rail) && {
    styleProps: _extends({}, styleProps, railProps.styleProps),
    theme
  }, {
    className: clsx(classes.rail, railProps.className)
  })), /*#__PURE__*/createElement(Track, _extends({}, trackProps, !isHostComponent(Track) && {
    styleProps: _extends({}, styleProps, trackProps.styleProps),
    theme
  }, {
    className: clsx(classes.track, trackProps.className),
    style: _extends({}, trackStyle, trackProps.style)
  })), marks.map((mark, index) => {
    const percent = valueToPercent(mark.value, min, max);
    const style = axisProps[axis].offset(percent);
    let markActive;

    if (track === false) {
      markActive = values.indexOf(mark.value) !== -1;
    } else {
      markActive = track === 'normal' && (range ? mark.value >= values[0] && mark.value <= values[values.length - 1] : mark.value <= values[0]) || track === 'inverted' && (range ? mark.value <= values[0] || mark.value >= values[values.length - 1] : mark.value >= values[0]);
    }

    return /*#__PURE__*/createElement(Fragment, {
      key: mark.value
    }, /*#__PURE__*/createElement(Mark, _extends({
      "data-index": index
    }, markProps, !isHostComponent(Mark) && {
      styleProps: _extends({}, styleProps, markProps.styleProps, {
        markActive
      }),
      theme
    }, {
      style: _extends({}, style, markProps.style),
      className: clsx(classes.mark, markProps.className, markActive && classes.markActive)
    })), mark.label != null ? /*#__PURE__*/createElement(MarkLabel, _extends({
      "aria-hidden": true,
      "data-index": index
    }, markLabelProps, !isHostComponent(MarkLabel) && {
      styleProps: _extends({}, styleProps, markLabelProps.styleProps, {
        markLabelActive: markActive
      }),
      theme
    }, {
      style: _extends({}, style, markLabelProps.style),
      className: clsx(classes.markLabel, markLabelProps.className, markActive && classes.markLabelActive)
    }), mark.label) : null);
  }), values.map((value, index) => {
    const percent = valueToPercent(value, min, max);
    const style = axisProps[axis].offset(percent);
    const ValueLabelComponent = valueLabelDisplay === 'off' ? Forward : ValueLabel;
    return /*#__PURE__*/createElement(Fragment, {
      key: index
    }, /*#__PURE__*/createElement(ValueLabelComponent, _extends({
      valueLabelFormat: valueLabelFormat,
      valueLabelDisplay: valueLabelDisplay,
      value: typeof valueLabelFormat === 'function' ? valueLabelFormat(scale(value), index) : valueLabelFormat,
      index: index,
      open: open === index || active === index || valueLabelDisplay === 'on',
      disabled: disabled
    }, valueLabelProps, {
      className: clsx(classes.valueLabel, valueLabelProps.className)
    }, !isHostComponent(ValueLabel) && {
      styleProps: _extends({}, styleProps, valueLabelProps.styleProps),
      theme
    }), /*#__PURE__*/createElement(Thumb, _extends({
      "data-index": index,
      onMouseOver: handleMouseOver,
      onMouseLeave: handleMouseLeave
    }, thumbProps, {
      className: clsx(classes.thumb, thumbProps.className, active === index && classes.active, focusVisible === index && classes.focusVisible)
    }, !isHostComponent(Thumb) && {
      styleProps: _extends({}, styleProps, thumbProps.styleProps),
      theme
    }, {
      style: _extends({}, style, thumbProps.style)
    }), /*#__PURE__*/createElement("input", {
      "data-index": index,
      "aria-label": getAriaLabel ? getAriaLabel(index) : ariaLabel,
      "aria-labelledby": ariaLabelledby,
      "aria-orientation": orientation,
      "aria-valuemax": scale(max),
      "aria-valuemin": scale(min),
      "aria-valuenow": scale(value),
      "aria-valuetext": getAriaValueText ? getAriaValueText(scale(value), index) : ariaValuetext,
      onFocus: handleFocus,
      onBlur: handleBlur,
      name: name,
      type: "range",
      min: props.min,
      max: props.max,
      step: props.step,
      disabled: disabled,
      value: values[index],
      onChange: handleHiddenInputChange,
      style: _extends({}, visuallyHidden, {
        direction: isRtl ? 'rtl' : 'ltr',
        // So that VoiceOver's focus indicator matches the thumb's dimensions
        width: '100%',
        height: '100%'
      })
    }))));
  }));
});
process.env.NODE_ENV !== "production" ? SliderUnstyled.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit the d.ts file and run "yarn proptypes"     |
  // ----------------------------------------------------------------------

  /**
   * The label of the slider.
   */
  'aria-label': chainPropTypes(propTypes.string, props => {
    const range = Array.isArray(props.value || props.defaultValue);

    if (range && props['aria-label'] != null) {
      return new Error('Material-UI: You need to use the `getAriaLabel` prop instead of `aria-label` when using a range slider.');
    }

    return null;
  }),

  /**
   * The id of the element containing a label for the slider.
   */
  'aria-labelledby': propTypes.string,

  /**
   * A string value that provides a user-friendly name for the current value of the slider.
   */
  'aria-valuetext': chainPropTypes(propTypes.string, props => {
    const range = Array.isArray(props.value || props.defaultValue);

    if (range && props['aria-valuetext'] != null) {
      return new Error('Material-UI: You need to use the `getAriaValueText` prop instead of `aria-valuetext` when using a range slider.');
    }

    return null;
  }),

  /**
   * @ignore
   */
  children: propTypes.node,

  /**
   * Override or extend the styles applied to the component.
   */
  classes: propTypes.object,

  /**
   * @ignore
   */
  className: propTypes.string,

  /**
   * The component used for the root node.
   * Either a string to use a HTML element or a component.
   */
  component: propTypes.elementType,

  /**
   * The components used for each slot inside the Slider.
   * Either a string to use a HTML element or a component.
   * @default {}
   */
  components: propTypes.shape({
    Mark: propTypes.elementType,
    MarkLabel: propTypes.elementType,
    Rail: propTypes.elementType,
    Root: propTypes.elementType,
    Thumb: propTypes.elementType,
    Track: propTypes.elementType,
    ValueLabel: propTypes.elementType
  }),

  /**
   * The props used for each slot inside the Slider.
   * @default {}
   */
  componentsProps: propTypes.object,

  /**
   * The default value. Use when the component is not controlled.
   */
  defaultValue: propTypes.oneOfType([propTypes.arrayOf(propTypes.number), propTypes.number]),

  /**
   * If `true`, the component is disabled.
   * @default false
   */
  disabled: propTypes.bool,

  /**
   * Accepts a function which returns a string value that provides a user-friendly name for the thumb labels of the slider.
   *
   * @param {number} index The thumb label's index to format.
   * @returns {string}
   */
  getAriaLabel: propTypes.func,

  /**
   * Accepts a function which returns a string value that provides a user-friendly name for the current value of the slider.
   *
   * @param {number} value The thumb label's value to format.
   * @param {number} index The thumb label's index to format.
   * @returns {string}
   */
  getAriaValueText: propTypes.func,

  /**
   * Indicates whether the theme context has rtl direction. It is set automatically.
   * @default false
   */
  isRtl: propTypes.bool,

  /**
   * Marks indicate predetermined values to which the user can move the slider.
   * If `true` the marks are spaced according the value of the `step` prop.
   * If an array, it should contain objects with `value` and an optional `label` keys.
   * @default false
   */
  marks: propTypes.oneOfType([propTypes.arrayOf(propTypes.shape({
    label: propTypes.node,
    value: propTypes.number.isRequired
  })), propTypes.bool]),

  /**
   * The maximum allowed value of the slider.
   * Should not be equal to min.
   * @default 100
   */
  max: propTypes.number,

  /**
   * The minimum allowed value of the slider.
   * Should not be equal to max.
   * @default 0
   */
  min: propTypes.number,

  /**
   * Name attribute of the hidden `input` element.
   */
  name: propTypes.string,

  /**
   * Callback function that is fired when the slider's value changed.
   *
   * @param {object} event The event source of the callback.
   * You can pull out the new value by accessing `event.target.value` (any).
   * **Warning**: This is a generic event not a change event.
   * @param {number | number[]} value The new value.
   */
  onChange: propTypes.func,

  /**
   * Callback function that is fired when the `mouseup` is triggered.
   *
   * @param {object} event The event source of the callback. **Warning**: This is a generic event not a change event.
   * @param {number | number[]} value The new value.
   */
  onChangeCommitted: propTypes.func,

  /**
   * @ignore
   */
  onMouseDown: propTypes.func,

  /**
   * The component orientation.
   * @default 'horizontal'
   */
  orientation: propTypes.oneOf(['horizontal', 'vertical']),

  /**
   * A transformation function, to change the scale of the slider.
   * @default (x) => x
   */
  scale: propTypes.func,

  /**
   * The granularity with which the slider can step through values. (A "discrete" slider.)
   * The `min` prop serves as the origin for the valid values.
   * We recommend (max - min) to be evenly divisible by the step.
   *
   * When step is `null`, the thumb can only be slid onto marks provided with the `marks` prop.
   * @default 1
   */
  step: propTypes.number,

  /**
   * The track presentation:
   *
   * - `normal` the track will render a bar representing the slider value.
   * - `inverted` the track will render a bar representing the remaining slider value.
   * - `false` the track will render without a bar.
   * @default 'normal'
   */
  track: propTypes.oneOf(['inverted', 'normal', false]),

  /**
   * The value of the slider.
   * For ranged sliders, provide an array with two values.
   */
  value: propTypes.oneOfType([propTypes.arrayOf(propTypes.number), propTypes.number]),

  /**
   * Controls when the value label is displayed:
   *
   * - `auto` the value label will display when the thumb is hovered or focused.
   * - `on` will display persistently.
   * - `off` will never display.
   * @default 'off'
   */
  valueLabelDisplay: propTypes.oneOf(['auto', 'off', 'on']),

  /**
   * The format function the value label's value.
   *
   * When a function is provided, it should have the following signature:
   *
   * - {number} value The value label's value to format
   * - {number} index The value label's index to format
   * @default (x) => x
   */
  valueLabelFormat: propTypes.oneOfType([propTypes.func, propTypes.string])
} : void 0;

const sliderClasses = _extends({}, sliderUnstyledClasses, generateUtilityClasses('MuiSlider', ['colorPrimary', 'colorSecondary', 'thumbColorPrimary', 'thumbColorSecondary']));

const overridesResolver = (props, styles) => {
  const {
    styleProps
  } = props;
  const marks = styleProps.marksProp === true && styleProps.step !== null ? [...Array(Math.floor((styleProps.max - styleProps.min) / styleProps.step) + 1)].map((_, index) => ({
    value: styleProps.min + styleProps.step * index
  })) : styleProps.marksProp || [];
  const marked = marks.length > 0 && marks.some(mark => mark.label);
  return deepmerge(_extends({}, styles[`color${capitalize(styleProps.color)}`], {
    [`&.${sliderClasses.disabled}`]: styles.disabled
  }, marked && styles.marked, styleProps.orientation === 'vertical' && styles.vertical, styleProps.track === 'inverted' && styles.trackInverted, styleProps.track === false && styles.trackFalse, {
    [`& .${sliderClasses.rail}`]: styles.rail,
    [`& .${sliderClasses.track}`]: styles.track,
    [`& .${sliderClasses.mark}`]: styles.mark,
    [`& .${sliderClasses.markLabel}`]: styles.markLabel,
    [`& .${sliderClasses.valueLabel}`]: styles.valueLabel,
    [`& .${sliderClasses.thumb}`]: _extends({}, styles.thumb, styles[`thumbColor${capitalize(styleProps.color)}`], {
      [`&.${sliderClasses.disabled}`]: styles.disabled
    })
  }), styles.root || {});
};

const SliderRoot = experimentalStyled('span', {}, {
  name: 'MuiSlider',
  slot: 'Root',
  overridesResolver
})(({
  theme,
  styleProps
}) => _extends({
  height: 2,
  width: '100%',
  boxSizing: 'content-box',
  padding: '13px 0',
  display: 'inline-block',
  position: 'relative',
  cursor: 'pointer',
  touchAction: 'none',
  color: theme.palette.primary.main,
  WebkitTapHighlightColor: 'transparent'
}, styleProps.color === 'secondary' && {
  color: theme.palette.secondary.main
}, {
  [`&.${sliderClasses.disabled}`]: {
    pointerEvents: 'none',
    cursor: 'default',
    color: theme.palette.grey[400]
  }
}, styleProps.orientation === 'vertical' && {
  width: 2,
  height: '100%',
  padding: '0 13px'
}, {
  // The primary input mechanism of the device includes a pointing device of limited accuracy.
  '@media (pointer: coarse)': _extends({
    // Reach 42px touch target, about ~8mm on screen.
    padding: '20px 0'
  }, styleProps.orientation === 'vertical' && {
    padding: '0 20px'
  }),
  '@media print': {
    colorAdjust: 'exact'
  }
}, styleProps.marked && _extends({
  marginBottom: 20
}, styleProps.orientation === 'vertical' && {
  marginBottom: 'auto',
  marginRight: 20
}), {
  [`& .${sliderClasses.valueLabelCircle}`]: {
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    width: 32,
    height: 32,
    borderRadius: '50% 50% 50% 0',
    backgroundColor: 'currentColor',
    transform: 'rotate(-45deg)'
  },
  [`& .${sliderClasses.valueLabelLabel}`]: {
    color: theme.palette.primary.contrastText,
    transform: 'rotate(45deg)',
    textAlign: 'center'
  },
  [`&.${sliderClasses.dragging}`]: {
    [`& .${sliderClasses.thumb}, & .${sliderClasses.track}`]: {
      transition: 'none'
    }
  }
}));
const SliderRail = experimentalStyled('span', {}, {
  name: 'MuiSlider',
  slot: 'Rail'
})(({
  styleProps
}) => _extends({
  display: 'block',
  position: 'absolute',
  width: '100%',
  height: 2,
  borderRadius: 1,
  backgroundColor: 'currentColor',
  opacity: 0.38
}, styleProps.orientation === 'vertical' && {
  height: '100%',
  width: 2
}, styleProps.track === 'inverted' && {
  opacity: 1
}));
const SliderTrack = experimentalStyled('span', {}, {
  name: 'MuiSlider',
  slot: 'Track'
})(({
  theme,
  styleProps
}) => _extends({
  display: 'block',
  position: 'absolute',
  height: 2,
  borderRadius: 1,
  backgroundColor: 'currentColor',
  transition: theme.transitions.create(['left', 'width'], {
    duration: theme.transitions.duration.shortest
  })
}, styleProps.orientation === 'vertical' && {
  width: 2
}, styleProps.track === false && {
  display: 'none'
}, styleProps.track === 'inverted' && {
  backgroundColor: // Same logic as the LinearProgress track color
  theme.palette.mode === 'light' ? lighten(theme.palette.primary.main, 0.62) : darken(theme.palette.primary.main, 0.5)
}));
const SliderThumb = experimentalStyled('span', {}, {
  name: 'MuiSlider',
  slot: 'Thumb'
})(({
  theme,
  styleProps
}) => _extends({
  position: 'absolute',
  width: 12,
  height: 12,
  marginLeft: -6,
  marginTop: -5,
  boxSizing: 'border-box',
  borderRadius: '50%',
  outline: 0,
  backgroundColor: 'currentColor',
  display: 'flex',
  alignItems: 'center',
  justifyContent: 'center',
  transition: theme.transitions.create(['box-shadow', 'left'], {
    duration: theme.transitions.duration.shortest
  }),
  '&::after': {
    position: 'absolute',
    content: '""',
    borderRadius: '50%',
    // reach 42px hit target (2 * 15 + thumb diameter)
    left: -15,
    top: -15,
    right: -15,
    bottom: -15
  },
  [`&:hover, &.${sliderClasses.focusVisible}`]: {
    boxShadow: `0px 0px 0px 8px ${alpha(theme.palette.primary.main, 0.16)}`,
    '@media (hover: none)': {
      boxShadow: 'none'
    }
  },
  [`&.${sliderClasses.active}`]: {
    boxShadow: `0px 0px 0px 14px ${alpha(theme.palette.primary.main, 0.16)}`
  },
  [`&.${sliderClasses.disabled}`]: _extends({
    width: 8,
    height: 8,
    marginLeft: -4,
    marginTop: -3
  }, styleProps.orientation === 'vertical' && {
    marginLeft: -3,
    marginBottom: -4
  }, {
    '&:hover': {
      boxShadow: 'none'
    }
  })
}, styleProps.orientation === 'vertical' && {
  marginLeft: -5,
  marginBottom: -6
}, styleProps.color === 'secondary' && {
  [`&:hover, &.${sliderClasses.focusVisible}`]: {
    boxShadow: `0px 0px 0px 8px ${alpha(theme.palette.secondary.main, 0.16)}`
  },
  [`&.${sliderClasses.active}`]: {
    boxShadow: `0px 0px 0px 14px ${alpha(theme.palette.secondary.main, 0.16)}`
  }
}));
const SliderValueLabel = experimentalStyled(SliderValueLabelUnstyled, {}, {
  name: 'MuiSlider',
  slot: 'ValueLabel'
})(({
  theme
}) => _extends({
  // IE 11 centering bug, to remove from the customization demos once no longer supported
  left: 'calc(-50% - 4px)',
  [`&.${sliderClasses.valueLabelOpen}`]: {
    transform: 'scale(1) translateY(-10px)'
  },
  zIndex: 1
}, theme.typography.body2, {
  fontSize: theme.typography.pxToRem(12),
  lineHeight: 1.2,
  transition: theme.transitions.create(['transform'], {
    duration: theme.transitions.duration.shortest
  }),
  top: -34,
  transformOrigin: 'bottom center',
  transform: 'scale(0)',
  position: 'absolute'
}));
const SliderMark = experimentalStyled('span', {}, {
  name: 'MuiSlider',
  slot: 'Mark'
})(({
  theme,
  styleProps
}) => _extends({
  position: 'absolute',
  width: 2,
  height: 2,
  borderRadius: 1,
  backgroundColor: 'currentColor'
}, styleProps.markActive && {
  backgroundColor: theme.palette.background.paper,
  opacity: 0.8
}));
const SliderMarkLabel = experimentalStyled('span', {}, {
  name: 'MuiSlider',
  slot: 'MarkLabel'
})(({
  theme,
  styleProps
}) => _extends({}, theme.typography.body2, {
  color: theme.palette.text.secondary,
  position: 'absolute',
  top: 26,
  transform: 'translateX(-50%)',
  whiteSpace: 'nowrap'
}, styleProps.orientation === 'vertical' && {
  top: 'auto',
  left: 26,
  transform: 'translateY(50%)'
}, {
  '@media (pointer: coarse)': _extends({
    top: 40
  }, styleProps.orientation === 'vertical' && {
    left: 31
  })
}, styleProps.markLabelActive && {
  color: theme.palette.text.primary
}));
SliderRoot.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit the d.ts file and run "yarn proptypes"     |
  // ----------------------------------------------------------------------

  /**
   * @ignore
   */
  children: propTypes.node,

  /**
   * @ignore
   */
  styleProps: propTypes.shape({
    'aria-label': propTypes.string,
    'aria-labelledby': propTypes.string,
    'aria-valuetext': propTypes.string,
    classes: propTypes.object,
    color: propTypes.oneOf(['primary', 'secondary']),
    defaultValue: propTypes.oneOfType([propTypes.arrayOf(propTypes.number), propTypes.number]),
    disabled: propTypes.bool,
    getAriaLabel: propTypes.func,
    getAriaValueText: propTypes.func,
    isRtl: propTypes.bool,
    marks: propTypes.oneOfType([propTypes.arrayOf(propTypes.shape({
      label: propTypes.node,
      value: propTypes.number.isRequired
    })), propTypes.bool]),
    max: propTypes.number,
    min: propTypes.number,
    name: propTypes.string,
    onChange: propTypes.func,
    onChangeCommitted: propTypes.func,
    orientation: propTypes.oneOf(['horizontal', 'vertical']),
    scale: propTypes.func,
    step: propTypes.number,
    track: propTypes.oneOf(['inverted', 'normal', false]),
    value: propTypes.oneOfType([propTypes.arrayOf(propTypes.number), propTypes.number]),
    valueLabelDisplay: propTypes.oneOf(['auto', 'off', 'on']),
    valueLabelFormat: propTypes.oneOfType([propTypes.func, propTypes.string])
  })
};

const extendUtilityClasses = styleProps => {
  const {
    color,
    classes = {}
  } = styleProps;
  return _extends({}, classes, {
    root: clsx(classes.root, getSliderUtilityClass(`color${capitalize(color)}`), classes[`color${capitalize(color)}`]),
    thumb: clsx(classes.thumb, getSliderUtilityClass(`thumbColor${capitalize(color)}`), classes[`thumbColor${capitalize(color)}`])
  });
};

const shouldSpreadStyleProps = Component => {
  return !Component || !isHostComponent(Component);
};

const Slider = /*#__PURE__*/forwardRef(function Slider(inputProps, ref) {
  var _componentsProps$root, _componentsProps$thum;

  const props = useThemeProps({
    props: inputProps,
    name: 'MuiSlider'
  });

  const {
    components = {},
    componentsProps = {},
    color = 'primary'
  } = props,
        other = _objectWithoutPropertiesLoose(props, ["components", "componentsProps", "color"]);

  const styleProps = _extends({}, props, {
    color
  });

  const classes = extendUtilityClasses(styleProps);
  return /*#__PURE__*/createElement(SliderUnstyled, _extends({}, other, {
    components: _extends({
      Root: SliderRoot,
      Rail: SliderRail,
      Track: SliderTrack,
      Thumb: SliderThumb,
      ValueLabel: SliderValueLabel,
      Mark: SliderMark,
      MarkLabel: SliderMarkLabel
    }, components),
    componentsProps: _extends({}, componentsProps, {
      root: _extends({}, componentsProps.root, shouldSpreadStyleProps(components.Root) && {
        styleProps: _extends({}, (_componentsProps$root = componentsProps.root) === null || _componentsProps$root === void 0 ? void 0 : _componentsProps$root.styleProps, {
          color
        })
      }),
      thumb: _extends({}, componentsProps.thumb, shouldSpreadStyleProps(components.Thumb) && {
        styleProps: _extends({}, (_componentsProps$thum = componentsProps.thumb) === null || _componentsProps$thum === void 0 ? void 0 : _componentsProps$thum.styleProps, {
          color
        })
      })
    }),
    classes: classes,
    ref: ref
  }));
});
process.env.NODE_ENV !== "production" ? Slider.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit the d.ts file and run "yarn proptypes"     |
  // ----------------------------------------------------------------------

  /**
   * The label of the slider.
   */
  'aria-label': chainPropTypes(propTypes.string, props => {
    const range = Array.isArray(props.value || props.defaultValue);

    if (range && props['aria-label'] != null) {
      return new Error('Material-UI: You need to use the `getAriaLabel` prop instead of `aria-label` when using a range slider.');
    }

    return null;
  }),

  /**
   * The id of the element containing a label for the slider.
   */
  'aria-labelledby': propTypes.string,

  /**
   * A string value that provides a user-friendly name for the current value of the slider.
   */
  'aria-valuetext': chainPropTypes(propTypes.string, props => {
    const range = Array.isArray(props.value || props.defaultValue);

    if (range && props['aria-valuetext'] != null) {
      return new Error('Material-UI: You need to use the `getAriaValueText` prop instead of `aria-valuetext` when using a range slider.');
    }

    return null;
  }),

  /**
   * @ignore
   */
  children: propTypes.node,

  /**
   * Override or extend the styles applied to the component.
   */
  classes: propTypes.object,

  /**
   * The color of the component. It supports those theme colors that make sense for this component.
   * @default 'primary'
   */
  color: propTypes.oneOf(['primary', 'secondary']),

  /**
   * The components used for each slot inside the Slider.
   * Either a string to use a HTML element or a component.
   * @default {}
   */
  components: propTypes.shape({
    Mark: propTypes.elementType,
    MarkLabel: propTypes.elementType,
    Rail: propTypes.elementType,
    Root: propTypes.elementType,
    Thumb: propTypes.elementType,
    Track: propTypes.elementType,
    ValueLabel: propTypes.elementType
  }),

  /**
   * The props used for each slot inside the Slider.
   * @default {}
   */
  componentsProps: propTypes.object,

  /**
   * The default value. Use when the component is not controlled.
   */
  defaultValue: propTypes.oneOfType([propTypes.arrayOf(propTypes.number), propTypes.number]),

  /**
   * If `true`, the component is disabled.
   * @default false
   */
  disabled: propTypes.bool,

  /**
   * Accepts a function which returns a string value that provides a user-friendly name for the thumb labels of the slider.
   *
   * @param {number} index The thumb label's index to format.
   * @returns {string}
   */
  getAriaLabel: propTypes.func,

  /**
   * Accepts a function which returns a string value that provides a user-friendly name for the current value of the slider.
   *
   * @param {number} value The thumb label's value to format.
   * @param {number} index The thumb label's index to format.
   * @returns {string}
   */
  getAriaValueText: propTypes.func,

  /**
   * Indicates whether the theme context has rtl direction. It is set automatically.
   * @default false
   */
  isRtl: propTypes.bool,

  /**
   * Marks indicate predetermined values to which the user can move the slider.
   * If `true` the marks are spaced according the value of the `step` prop.
   * If an array, it should contain objects with `value` and an optional `label` keys.
   * @default false
   */
  marks: propTypes.oneOfType([propTypes.arrayOf(propTypes.shape({
    label: propTypes.node,
    value: propTypes.number.isRequired
  })), propTypes.bool]),

  /**
   * The maximum allowed value of the slider.
   * Should not be equal to min.
   * @default 100
   */
  max: propTypes.number,

  /**
   * The minimum allowed value of the slider.
   * Should not be equal to max.
   * @default 0
   */
  min: propTypes.number,

  /**
   * Name attribute of the hidden `input` element.
   */
  name: propTypes.string,

  /**
   * Callback function that is fired when the slider's value changed.
   *
   * @param {object} event The event source of the callback.
   * You can pull out the new value by accessing `event.target.value` (any).
   * **Warning**: This is a generic event not a change event.
   * @param {number | number[]} value The new value.
   */
  onChange: propTypes.func,

  /**
   * Callback function that is fired when the `mouseup` is triggered.
   *
   * @param {object} event The event source of the callback. **Warning**: This is a generic event not a change event.
   * @param {number | number[]} value The new value.
   */
  onChangeCommitted: propTypes.func,

  /**
   * The component orientation.
   * @default 'horizontal'
   */
  orientation: propTypes.oneOf(['horizontal', 'vertical']),

  /**
   * A transformation function, to change the scale of the slider.
   * @default (x) => x
   */
  scale: propTypes.func,

  /**
   * The granularity with which the slider can step through values. (A "discrete" slider.)
   * The `min` prop serves as the origin for the valid values.
   * We recommend (max - min) to be evenly divisible by the step.
   *
   * When step is `null`, the thumb can only be slid onto marks provided with the `marks` prop.
   * @default 1
   */
  step: propTypes.number,

  /**
   * The system prop that allows defining system overrides as well as additional CSS styles.
   */
  sx: propTypes.object,

  /**
   * The track presentation:
   *
   * - `normal` the track will render a bar representing the slider value.
   * - `inverted` the track will render a bar representing the remaining slider value.
   * - `false` the track will render without a bar.
   * @default 'normal'
   */
  track: propTypes.oneOf(['inverted', 'normal', false]),

  /**
   * The value of the slider.
   * For ranged sliders, provide an array with two values.
   */
  value: propTypes.oneOfType([propTypes.arrayOf(propTypes.number), propTypes.number]),

  /**
   * Controls when the value label is displayed:
   *
   * - `auto` the value label will display when the thumb is hovered or focused.
   * - `on` will display persistently.
   * - `off` will never display.
   * @default 'off'
   */
  valueLabelDisplay: propTypes.oneOf(['auto', 'off', 'on']),

  /**
   * The format function the value label's value.
   *
   * When a function is provided, it should have the following signature:
   *
   * - {number} value The value label's value to format
   * - {number} index The value label's index to format
   * @default (x) => x
   */
  valueLabelFormat: propTypes.oneOfType([propTypes.func, propTypes.string])
} : void 0;

var makeSliderStyles = makeStyles(function (theme) { return ({
    track: {
        height: 4,
    },
    rail: {
        height: 4,
    },
    thumb: {
        marginTop: -4,
        boxShadow: '0px 1px 5px rgba(45, 166, 186, 0.12), 0px 3px 1px rgba(45, 166, 186, 0.2), 0px 2px 4px rgba(45, 166, 186, 0.14)',
    },
    mark: {
        display: 'none',
    },
}); });
var AppValidateSlider = function (props) {
    var _a;
    var sliderStyles = makeSliderStyles();
    var _b = useFormikContext(), values = _b.values, setFieldValue = _b.setFieldValue, setFieldTouched = _b.setFieldTouched, errors = _b.errors, touched = _b.touched;
    var name = props.name || 'name';
    props.inputStep; props.useInput; var onValueChangeHandler = props.onValueChangeHandler, sliderProps = __rest(props, ["inputStep", "useInput", "onValueChangeHandler"]);
    var minRange = props.min != null ? props.min : 0;
    var maxRange = props.max != null ? props.max : 100;
    var stepRange = props.step != null ? props.step : 1;
    var ariaLabelledBy = (_a = props['aria-labelledby']) !== null && _a !== void 0 ? _a : 'input-slider';
    var error = useMemo(function () {
        return get_1(touched, name) ? get_1(errors, name) : '';
    }, [touched, name, errors]);
    var handleSliderChange = function (event, newValue) {
        if (!get_1(touched, name)) {
            setFieldTouched(name);
        }
        if (Array.isArray(newValue)) {
            setFieldValue(name, newValue[0]);
        }
        if (typeof newValue === 'number') {
            setFieldValue(name, newValue);
        }
    };
    var handleInputChange = function (event) {
        if (!get_1(touched, name)) {
            setFieldTouched(name);
        }
        var value = Number(event.target.value);
        handleValueChange(Number.isNaN(value) ? 0 : value);
    };
    var callbackHandler = debounce_1(function (newValue) {
        if (!onValueChangeHandler)
            return;
        return onValueChangeHandler(newValue, name, setFieldValue);
    }, 100);
    var handleValueChange = function (newValue) {
        setFieldValue(name, newValue);
        callbackHandler(newValue);
    };
    var handleSliderMouseUp = function (event, newValue) {
        var value = Array.isArray(newValue) ? newValue[0] : newValue;
        handleValueChange(value);
    };
    var handleInputBlur = function () {
        var value = get_1(values, name);
        if (value < minRange) {
            setFieldValue(name, minRange);
        }
        else if (value > maxRange) {
            setFieldValue(name, maxRange);
        }
    };
    return (jsxs(Grid, __assign({ container: true, spacing: 2, alignItems: "center" }, { children: [jsx(Grid, __assign({ item: true, xs: props.useInput ? 9 : 12 }, { children: jsx(Slider, __assign({}, sliderProps, { value: get_1(values, name), min: minRange, max: maxRange, step: stepRange, "aria-labelledby": ariaLabelledBy, component: "span", classes: sliderProps.classes || sliderStyles, onChange: handleSliderChange, onChangeCommitted: handleSliderMouseUp }), void 0) }), void 0),
            props.useInput && (jsx(Grid, __assign({ item: true, xs: 3 }, { children: jsx(Input, { value: get_1(values, name), margin: "dense", onChange: handleInputChange, onBlur: handleInputBlur, style: { transform: 'translateY(-25px)' }, inputProps: {
                        step: props.inputStep || stepRange,
                        min: minRange,
                        max: maxRange,
                        type: 'number',
                        'aria-labelledby': ariaLabelledBy,
                    } }, void 0) }), void 0)),
            error && (jsx(Grid, __assign({ item: true, xs: 12, className: "pt-0" }, { children: jsx("p", __assign({ className: "error text-3" }, { children: error }), void 0) }), void 0))] }), void 0));
};

export default AppValidateSlider;
//# sourceMappingURL=AppValidateSlider.js.map
